@@ -6,19 +6,25 @@
 """
 
 from ._version import __version__ as version
-from .analytics import AnalyzerBuilder, AnalyzerFacade
+from .analytics import AnalyzerFacade
 from .authentication.auth import CalendarAuth
 from .collecting.collector import AsyncCalendarDataCollector
-from .processing.transformer import (AsyncDataTransformer,
-                                     EventDurationPeriodsStrategy,
-                                     ManyEventsDurationStrategy,
-                                     OneEventDurationStrategy)
-from .visualization.visualizer_factory import (BarPlot, LinePlot,
-                                               MultyLinePlot, PiePlot,
-                                               PlotFactory)
+from .processing.transformer import (
+    AsyncDataTransformer,
+    EventDurationPeriodsStrategy,
+    ManyEventsDurationStrategy,
+    OneEventDurationStrategy,
+)
+from .visualization.visualizer_factory import (
+    BarPlot,
+    LinePlot,
+    MultyLinePlot,
+    PiePlot,
+    PlotFactory,
+)
+from .visualization.visual_design import VisualDesign, base_plot_design
 
 __all__ = [
-    "AnalyzerBuilder",
     "AnalyzerFacade",
     "AsyncCalendarDataCollector",
     "AsyncDataTransformer",
@@ -31,6 +37,8 @@ __all__ = [
     "OneEventDurationStrategy",
     "PiePlot",
     "PlotFactory",
+    "VisualDesign",
+    "base_plot_design",
 ]
 
 __author__ = "Berupor"
